"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const lodashEs = require("lodash-es");
const index = require("./index-OTTYrRf9.cjs");
const defaultApiConfig = {
  baseUrl: "",
  requestTimeout: -1,
  successCode: 0,
  needLoginCode: [630],
  tenant: () => null,
  authToken: () => null,
  autoLogin: () => Promise.reject(new Error("autoLogin not implemented")),
  defaultHeaders: {},
  defaultParams: {},
  proxy: false
};
let apiConfig = { ...defaultApiConfig };
let request = null;
const setupApi = (requestProvider, config) => {
  if (config) {
    apiConfig = lodashEs.extend(apiConfig, config);
  }
  request = requestProvider(apiConfig);
};
const useRequest = () => {
  if (!request) {
    throw new Error("Please call `setupApi()` before useRequest");
  }
  return request;
};
const fetch = async ({ url, method, headers, params, data, contentType, responseType, timeout, onProgress, baseURL }) => {
  const res = await useRequest()({
    baseURL,
    url,
    method: method || "get",
    params: index.toSnakeObject(params),
    data,
    responseType,
    headers: {
      ...headers,
      "Content-Type": contentType || "application/json"
    },
    timeout,
    onUploadProgress: onProgress,
    onDownloadProgress: onProgress
  });
  if (res.status !== 200) {
    throw new Error(res.statusText);
  }
  return index.toCamleObject(res.data);
};
const upload = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: config.method || "post",
    headers: config.headers,
    params: config.params,
    data: config.data,
    contentType: "multipart/form-data",
    responseType: config.responseType,
    timeout: config.timeout | 36e5,
    onProgress: config.onProgress
  });
};
const get = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "get",
    headers: config.headers,
    params: config.params,
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const post = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "post",
    headers: config.headers,
    params: config.params,
    data: { body: index.toSnakeObject(config.data) },
    contentType: config.contentType,
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const getPage = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "get",
    headers: config.headers,
    params: lodashEs.extend(config.params, config.page, config.sort),
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const postPage = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "post",
    headers: config.headers,
    params: lodashEs.extend(config.params, config.page, config.sort),
    data: { body: index.toSnakeObject(config.data) },
    contentType: config.contentType,
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const defineUploadApi = (config, defaultParam) => {
  return (data, param, onProgress) => {
    return upload({ ...config, params: lodashEs.extend({}, defaultParam, param), data, onProgress: onProgress ?? config.onProgress });
  };
};
const defineGetApi = (config, defaultParam) => {
  return (param) => {
    return get({ ...config, params: lodashEs.extend({}, defaultParam, param) });
  };
};
const defineGetPageApi = (config, defaultParam) => {
  return (params, page, sort) => {
    return getPage({ ...config, params: lodashEs.extend({}, defaultParam, params), page, sort });
  };
};
const definePostApi = (config, defaultParam) => {
  return (data, param) => {
    return post({ ...config, params: lodashEs.extend({}, defaultParam, param), data });
  };
};
const definePostPageApi = (config, defaultParam) => {
  return (data, page, param, sort) => {
    return postPage({ ...config, params: lodashEs.extend({}, defaultParam, param), data, page, sort });
  };
};
const defineListApi = (url, defaultParam) => {
  return (data, page, sort) => {
    return postPage({ url, params: lodashEs.extend({}, defaultParam), data, page, sort });
  };
};
const defineGetOneApi = (url) => {
  return (id) => {
    return get({ url, params: lodashEs.extend({}, { id }) });
  };
};
const defineAddOneApi = (url) => {
  return (data) => {
    return post({ url, data });
  };
};
const defineUpdateOneApi = (url) => {
  return (id, data) => {
    return post({ url, params: { id }, data });
  };
};
const defineDeleteApi = (url) => {
  return (ids) => {
    return get({ url, params: { ids: lodashEs.join(index.asArray(ids), ",") } });
  };
};
const defineChangeStatusApi = (url) => {
  return (ids, status) => {
    return post({ url, params: { ids: lodashEs.join(index.asArray(ids), ","), status } });
  };
};
const defineCrudApi = (config, defaultParam) => {
  const getFn = lodashEs.isFunction(config.get) ? config.get : defineGetOneApi(`${config.path || ""}/${config.get || "id"}`);
  const listFn = lodashEs.isFunction(config.list) ? config.list : defineListApi(`${config.path || ""}/${config.list || "list"}`, defaultParam);
  const addFn = lodashEs.isFunction(config.add) ? config.add : defineAddOneApi(`${config.path || ""}/${config.add || "add"}`);
  const updateFn = lodashEs.isFunction(config.update) ? config.update : defineUpdateOneApi(`${config.path || ""}/${config.update || "update"}`);
  const delsFn = lodashEs.isFunction(config.delete) ? config.delete : defineDeleteApi(`${config.path || ""}/${config.delete || "delete"}`);
  const changeStatusFn = lodashEs.isFunction(config.status) ? config.status : defineChangeStatusApi(`${config.path || ""}/${config.status || "status"}`);
  return {
    getOne: getFn,
    listPage: listFn,
    addOne: addFn,
    updateOne: updateFn,
    delete: delsFn,
    changeStatus: changeStatusFn
  };
};
const defineTreeApi = (path) => {
  const getTree = (parentId) => {
    return get({ url: `${path}/tree`, params: { parentId } });
  };
  const getPickerTree = (parentId) => {
    return get({ url: `${path}/picker-tree`, params: { parentId } });
  };
  const getSearch = (data, page) => {
    return postPage({ url: `${path}/search`, data, page });
  };
  return {
    getTree,
    getPickerTree,
    getSearch
  };
};
const nopMessageFun = () => {
  console.warn("Please use `setupDinoCore({msgHandlers:H})` or `provide(MessageSymbol)` first before call `useMessage()`");
};
const nopMessageHandler = {
  success: nopMessageFun,
  info: nopMessageFun,
  warning: nopMessageFun,
  error: nopMessageFun
};
const setupDinoCore = (config) => {
  index.setupMessage(config.message ?? nopMessageHandler);
  setupApi(config.requestProvider, config.api);
};
exports.asArray = index.asArray;
exports.awaitGet = index.awaitGet;
exports.isPromise = index.isPromise;
exports.setupMessage = index.setupMessage;
exports.toCamleObject = index.toCamleObject;
exports.toSnakeObject = index.toSnakeObject;
exports.useID = index.useID;
exports.useMessage = index.useMessage;
exports.defaultApiConfig = defaultApiConfig;
exports.defineAddOneApi = defineAddOneApi;
exports.defineChangeStatusApi = defineChangeStatusApi;
exports.defineCrudApi = defineCrudApi;
exports.defineDeleteApi = defineDeleteApi;
exports.defineGetApi = defineGetApi;
exports.defineGetOneApi = defineGetOneApi;
exports.defineGetPageApi = defineGetPageApi;
exports.defineListApi = defineListApi;
exports.definePostApi = definePostApi;
exports.definePostPageApi = definePostPageApi;
exports.defineTreeApi = defineTreeApi;
exports.defineUpdateOneApi = defineUpdateOneApi;
exports.defineUploadApi = defineUploadApi;
exports.fetch = fetch;
exports.get = get;
exports.getPage = getPage;
exports.post = post;
exports.postPage = postPage;
exports.setupApi = setupApi;
exports.setupDinoCore = setupDinoCore;
exports.upload = upload;
exports.useRequest = useRequest;
