import { extend, join, isFunction } from "lodash-es";
import { t as toSnakeObject, a as toCamleObject, b as asArray, s as setupMessage } from "./index-2PpROqgp.js";
import { c, i, u, d } from "./index-2PpROqgp.js";
const defaultApiConfig = {
  baseUrl: "",
  requestTimeout: -1,
  successCode: 0,
  needLoginCode: [630],
  tenant: () => null,
  authToken: () => null,
  autoLogin: () => Promise.reject(new Error("autoLogin not implemented")),
  defaultHeaders: {},
  defaultParams: {},
  proxy: false
};
let apiConfig = { ...defaultApiConfig };
let request = null;
const setupApi = (requestProvider, config) => {
  if (config) {
    apiConfig = extend(apiConfig, config);
  }
  request = requestProvider(apiConfig);
};
const useRequest = () => {
  if (!request) {
    throw new Error("Please call `setupApi()` before useRequest");
  }
  return request;
};
const fetch = async ({ url, method, headers, params, data, contentType, responseType, timeout, onProgress, baseURL }) => {
  const res = await useRequest()({
    baseURL,
    url,
    method: method || "get",
    params: toSnakeObject(params),
    data,
    responseType,
    headers: {
      ...headers,
      "Content-Type": contentType || "application/json"
    },
    timeout,
    onUploadProgress: onProgress,
    onDownloadProgress: onProgress
  });
  if (res.status !== 200) {
    throw new Error(res.statusText);
  }
  return toCamleObject(res.data);
};
const upload = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: config.method || "post",
    headers: config.headers,
    params: config.params,
    data: config.data,
    contentType: "multipart/form-data",
    responseType: config.responseType,
    timeout: config.timeout | 36e5,
    onProgress: config.onProgress
  });
};
const get = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "get",
    headers: config.headers,
    params: config.params,
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const post = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "post",
    headers: config.headers,
    params: config.params,
    data: { body: toSnakeObject(config.data) },
    contentType: config.contentType,
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const getPage = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "get",
    headers: config.headers,
    params: extend(config.params, config.page, config.sort),
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const postPage = (config) => {
  return fetch({
    url: config.url,
    baseURL: config.baseURL,
    method: "post",
    headers: config.headers,
    params: extend(config.params, config.page, config.sort),
    data: { body: toSnakeObject(config.data) },
    contentType: config.contentType,
    responseType: config.responseType,
    timeout: config.timeout
  });
};
const defineUploadApi = (config, defaultParam) => {
  return (data, param, onProgress) => {
    return upload({ ...config, params: extend({}, defaultParam, param), data, onProgress: onProgress ?? config.onProgress });
  };
};
const defineGetApi = (config, defaultParam) => {
  return (param) => {
    return get({ ...config, params: extend({}, defaultParam, param) });
  };
};
const defineGetPageApi = (config, defaultParam) => {
  return (params, page, sort) => {
    return getPage({ ...config, params: extend({}, defaultParam, params), page, sort });
  };
};
const definePostApi = (config, defaultParam) => {
  return (data, param) => {
    return post({ ...config, params: extend({}, defaultParam, param), data });
  };
};
const definePostPageApi = (config, defaultParam) => {
  return (data, page, param, sort) => {
    return postPage({ ...config, params: extend({}, defaultParam, param), data, page, sort });
  };
};
const defineListApi = (url, defaultParam) => {
  return (data, page, sort) => {
    return postPage({ url, params: extend({}, defaultParam), data, page, sort });
  };
};
const defineGetOneApi = (url) => {
  return (id) => {
    return get({ url, params: extend({}, { id }) });
  };
};
const defineAddOneApi = (url) => {
  return (data) => {
    return post({ url, data });
  };
};
const defineUpdateOneApi = (url) => {
  return (id, data) => {
    return post({ url, params: { id }, data });
  };
};
const defineDeleteApi = (url) => {
  return (ids) => {
    return get({ url, params: { ids: join(asArray(ids), ",") } });
  };
};
const defineChangeStatusApi = (url) => {
  return (ids, status) => {
    return post({ url, params: { ids: join(asArray(ids), ","), status } });
  };
};
const defineCrudApi = (config, defaultParam) => {
  const getFn = isFunction(config.get) ? config.get : defineGetOneApi(`${config.path || ""}/${config.get || "id"}`);
  const listFn = isFunction(config.list) ? config.list : defineListApi(`${config.path || ""}/${config.list || "list"}`, defaultParam);
  const addFn = isFunction(config.add) ? config.add : defineAddOneApi(`${config.path || ""}/${config.add || "add"}`);
  const updateFn = isFunction(config.update) ? config.update : defineUpdateOneApi(`${config.path || ""}/${config.update || "update"}`);
  const delsFn = isFunction(config.delete) ? config.delete : defineDeleteApi(`${config.path || ""}/${config.delete || "delete"}`);
  const changeStatusFn = isFunction(config.status) ? config.status : defineChangeStatusApi(`${config.path || ""}/${config.status || "status"}`);
  return {
    getOne: getFn,
    listPage: listFn,
    addOne: addFn,
    updateOne: updateFn,
    delete: delsFn,
    changeStatus: changeStatusFn
  };
};
const defineTreeApi = (path) => {
  const getTree = (parentId) => {
    return get({ url: `${path}/tree`, params: { parentId } });
  };
  const getPickerTree = (parentId) => {
    return get({ url: `${path}/picker-tree`, params: { parentId } });
  };
  const getSearch = (data, page) => {
    return postPage({ url: `${path}/search`, data, page });
  };
  return {
    getTree,
    getPickerTree,
    getSearch
  };
};
const nopMessageFun = () => {
  console.warn("Please use `setupDinoCore({msgHandlers:H})` or `provide(MessageSymbol)` first before call `useMessage()`");
};
const nopMessageHandler = {
  success: nopMessageFun,
  info: nopMessageFun,
  warning: nopMessageFun,
  error: nopMessageFun
};
const setupDinoCore = (config) => {
  setupMessage(config.message ?? nopMessageHandler);
  setupApi(config.requestProvider, config.api);
};
export {
  asArray,
  c as awaitGet,
  defaultApiConfig,
  defineAddOneApi,
  defineChangeStatusApi,
  defineCrudApi,
  defineDeleteApi,
  defineGetApi,
  defineGetOneApi,
  defineGetPageApi,
  defineListApi,
  definePostApi,
  definePostPageApi,
  defineTreeApi,
  defineUpdateOneApi,
  defineUploadApi,
  fetch,
  get,
  getPage,
  i as isPromise,
  post,
  postPage,
  setupApi,
  setupDinoCore,
  setupMessage,
  toCamleObject,
  toSnakeObject,
  upload,
  u as useID,
  d as useMessage,
  useRequest
};
